#
# spec file for package gnome-initial-setup
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-initial-setup
Version:        41.4
Release:        150400.1.9
Summary:        GNOME Initial Setup Assistant
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Design/OS/InitialSetup
Source0:        https://download.gnome.org/sources/gnome-initial-setup/41/%{name}-%{version}.tar.xz

BuildRequires:  krb5-devel
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(cheese) >= 3.28
BuildRequires:  pkgconfig(cheese-gtk) >= 3.3.5
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gdm) >= 3.8.3
BuildRequires:  pkgconfig(geocode-glib-1.0)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.53.0
BuildRequires:  pkgconfig(gnome-desktop-3.0) >= 3.7.5
BuildRequires:  pkgconfig(goa-1.0)
BuildRequires:  pkgconfig(goa-backend-1.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.37.1
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.11.3
BuildRequires:  pkgconfig(gweather-3.0)
BuildRequires:  pkgconfig(ibus-1.0) >= 1.4.99
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libgeoclue-2.0) >= 2.3.1
BuildRequires:  pkgconfig(libnm) >= 1.2
BuildRequires:  pkgconfig(libnma) >= 1.0
BuildRequires:  pkgconfig(libsecret-1) >= 0.18.8
BuildRequires:  pkgconfig(pango) >= 1.32.5
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.103
BuildRequires:  pkgconfig(pwquality)
BuildRequires:  pkgconfig(rest-0.7)
BuildRequires:  pkgconfig(systemd) >= 242
BuildRequires:  pkgconfig(webkit2gtk-4.0) >= 2.26.0
# Remove the yelp document dependency on both sle and leap, keeping tw consistent with upstream
%if !0%{?sle_version}
Requires:       gnome-getting-started-docs
%endif

%description
Initial assistant, helping you to get the system up and running.

%lang_package

%prep
%setup -q

%build
%meson \
        -Dparental_controls=disabled \
%if 0%{?sle_version} && 0%{?sle_version} < 160000
        -Dsystemd=false \
%endif
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%pre
useradd -rM -d /run/gnome-initial-setup/ -s /sbin/nologin %{name} || :

%files
%license COPYING
%doc README.md
%{_datadir}/applications/gnome-initial-setup.desktop
%dir %{_datadir}/gnome-session
%dir %{_datadir}/gnome-session/sessions
%{_datadir}/gnome-session/sessions/gnome-initial-setup.session
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/modes
%{_datadir}/gnome-shell/modes/initial-setup.json
%{_datadir}/polkit-1/rules.d/20-gnome-initial-setup.rules
%{_libexecdir}/gnome-initial-setup
%{_libexecdir}/gnome-initial-setup-copy-worker
%{_sysconfdir}/xdg/autostart/gnome-initial-setup-copy-worker.desktop
%{_sysconfdir}/xdg/autostart/gnome-initial-setup-first-login.desktop
%if !0%{?sle_version} || 0%{?sle_version} >= 160000
%{_userunitdir}/gnome-initial-setup-copy-worker.service
%{_userunitdir}/gnome-initial-setup-first-login.service
%dir %{_userunitdir}/gnome-session@gnome-initial-setup.target.d
%{_userunitdir}/gnome-session@gnome-initial-setup.target.d/session.conf
%dir %{_userunitdir}/gnome-session.target.wants
%{_userunitdir}/gnome-session.target.wants/gnome-initial-setup-copy-worker.service
%{_userunitdir}/gnome-session.target.wants/gnome-initial-setup-first-login.service
%endif

%files lang -f %{name}.lang

%changelog
* Thu Feb 10 2022 bjorn.lie@gmail.com
- Update to version 41.4:
  + Fix build failure with recent Meson releases.
  + Updated translations.
* Fri Dec  3 2021 bjorn.lie@gmail.com
- Update to version 41.2:
  + Updated translations.
* Fri Sep 17 2021 dimstar@opensuse.org
- Update to version 41.0:
  + Bug fixed: software: call fedora-third-party properly.
  + Updated translations.
* Mon Sep  6 2021 dimstar@opensuse.org
- Update to version 41.rc:
  + Fix the polkit rule for Fedora third party setup.
  + Updated translations.
* Tue Aug 24 2021 dimstar@opensuse.org
- Update to version 41.beta:
  + The Software page, which allows the user to enable or disable
    third-party repositories, has been resurrected. It is currently
    Fedora-specific.
  + Bug fixed: Cannot login as administrator if you set up
    enterprise login in gnome-initial-setup.
  + Updated translations.
* Sun Aug 15 2021 bjorn.lie@gmail.com
- Update to version 40.4:
  + Bugs fixed: glgo#GNOME/gnome-initial-setup!119 timezone: fix
    critical on startup when geoclue is disabled.
* Fri Jul 16 2021 qzhao@suse.com
- Drop gnome-initial-setup-smarter.patch: Because the function has
  moved to gnome-shell gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch
  in the latest Epic (jsc#SLE-16051, bsc#1184106);
* Tue Jul 13 2021 bjorn.lie@gmail.com
- Update to version 40.3:
  + Updated translations.
- Changes from version 40.2:
  + Updated translations.
* Fri Apr 30 2021 dimstar@opensuse.org
- Update to version 40.1:
  + The welcome page, displayed on systems where the language page
    is skipped, features an illustration of a computer on a desk.
    This illustration has been adjusted to make the hardware more
    generic.
  + Fix a small memory leak in language page.
  + Updated translations.
* Sat Mar 20 2021 mgorse@suse.com
- Update to version 40.0:
  + No changes.
* Thu Mar 18 2021 dimstar@opensuse.org
- Update to version 40.rc:
  + Updated translations.
* Tue Feb 16 2021 dimstar@opensuse.org
- Update to version 40.beta:
  + Completing GNOME Initial Setup no longer triggers GNOME Tour.
    GNOME Shell 40 now prompts new and upgrading users to run the
    tour.
  + Previous versions of Initial Setup would run the first time a
    user logs in ("existing user" mode) as well as when the system
    is booted with no users ("new user" mode). Initial Setup no
    longer displays any UI in "existing user" mode, to avoid
    colliding with the tour. The mode has not been removed in code.
  + A simple check has been added to the main() function. If your
    distribution needs the old behaviour, this check can be patched
    out. The hope is that a future version of GNOME will restore
    "existing user" mode, but run Initial Setup from the same
    cut-down Shell that is used in "new user" mode.
  + Initial Setup's .desktop file is now installed to
    @datadir@/applications rather than a GDM-specific directory.
    This means its icon is displayed correctly when run within a
    normal shell session. Some distros have previously worked
    around this issue by installing a symbolic link.
* Tue Feb 16 2021 dimstar@opensuse.org
- Update to version 40.alpha:
  + Some enhancements to the avatar picker:
  - The "Take a photo…" button now has the suggested-action
    style.
  - Generated avatars now have a darker border.
  - Fix runtime warning when built without libcheese.
  + The "Welcome" page, displayed when the language picker is
    disabled, has a refreshed splash image.
  + Updated translations.
* Mon Feb 15 2021 bjorn.lie@gmail.com
- Update to version 3.38.4:
  + Fix a small memory leak in timezone page.
* Thu Jan  7 2021 bjorn.lie@gmail.com
- Update to version 3.38.3:
  + Updated translations.
* Mon Nov 23 2020 dimstar@opensuse.org
- Update to version 3.38.2:
  + Fix error when not building with Cheese.
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Fix the window sometimes opens at an unusably small size,
    rather than being sized appropriately for the display. The fix
    causes a regression where the window doesn't react to the
    display size changing in all cases, but the new behaviour is
    better than the old.
  + Other bugs fixed:
  - docs: Remove typo from DEBUGGING.md.
  - Misc use-after-free and critical warning fixes.
  - data: Leave to meson the duty of keeping the lists in sync.
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sun Sep  6 2020 mgorse@suse.com
- Update to version 3.37.92:
  + Bugs fixed: Exit gracefully if we are disabled systemwide by
    Anacontda.
  + Updated translations.
- Changes in version 3.37.91.1:
  + Bugs fixed:
  - !92 gnome-initial-setup: Allow welcome tour to be skipped via vendor config.
  - !95 network: Re-word the description for Wi-Fi.
  - !100: Avoid a warning about connecting to a NULL object.
- Changes in version 3.37.91:
  + Revamp the ‘welcome screen.
  + Changes in version 3.37.90:
  + Use `gnome-tour` instead of `yelp` to start the welcome tour.
  + Switch to a new user session management approach of defining
    the session services in
    `gnome-session@gnome-initial-setup.target.d/session.conf` in
    the systemd user unit directory. This bumps the optional
    systemd dependency to ≥ 242.
- Changes in version 3.37.3:
  + The avatars offered in the 'account' page can now be customized
    by setting the 'org.gnome.desktop.interface avatar-directories'
    GSetting, which also controls the avatars offered in Settings.
  + Since version 3.30, it has been possible to customize certain
    aspects of Initial Setup by specifing the 'vendor-conf-file'
    option at build time, then installing a configuration file to
    that path. This version adds two paths that will be checked by
    default: one for distribution configuration, and another to
    override that configuration on specific deployments.
  + Bugs fixed:
  - timezone: Don't set timezone if tz page is skipped.
  - Polkit rules seem to list now unneeded privileges.
  - Add error argument to save_data() vfunc.
  - account: Use facesdirs setting to override faces.
  - Enable web process sandbox.
- Add >= 242 to systemd BuildRequires.
- Add >= 2.26.0 to webkit2gtk BuildRequires.
- Add gsettings-desktop-schemas to BuildRequires: new dependency.
* Sun Jul  5 2020 bjorn.lie@gmail.com
- Update to version 3.36.4:
  + Bugs fixed: timezone: Don't set timezone if tz page is skipped.
  + Updated translations.
* Mon Jun 15 2020 yfjiang@suse.com
- Update gnome-initial-setup.spec: Start gnome-initial-setup via
  xdg autostart as an alternative to systemd user units on
  SLE-15-SP2 and Leap 15.2 (bsc#1172910).
* Thu Jun  4 2020 bjorn.lie@gmail.com
- Update to version 3.36.3:
  + Bugs fixed: Japanese (Kana Kanji) no longer the default input
    method for Japanese in 3.36.2.
* Sun Apr 26 2020 bjorn.lie@gmail.com
- Update to version 3.36.2:
  + Bugs fixed: keyboard: Nullify pointers if getting layout fails.
  + Updated translations.
* Wed Apr 15 2020 qzhao@suse.com
- Update gnome-initial-setup.spec: Drop the is_opensuse macro to
  eliminate in behavior in between SLE-15 and openSUSE-Leap
  (jsc#SLE-11857).
* Sat Mar 28 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Previous releases of gnome-initial-setup had an unversioned
    dependency on libsecret; this release requires libsecret ≥
    0.18.8.
  + Bugs fixed:
  - account: Make parent account usable in case of errors
  - Improve readability when removing event sources
  - Fix two crashes when saving parental controls settings
  - Use g_auto and g_autoptr more
  + Updated translations.
* Fri Mar  6 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Updated translations.
* Sat Feb 29 2020 mgorse@suse.com
- Update to version 3.35.92:
  + Tweaks to the parental controls functionality introduced in
    the last release.
  + Updated translations.
* Tue Feb 18 2020 dimstar@opensuse.org
- Update to version 3.35.91:
  + New pages have been added to set up parental controls for the
    new user account. They are shown (or not, by default) based on
    a checkbox on the (local) user creation page.
  + When running under JHBuild, gnome-keyring is left untouched,
    and state is not saved when setup is complete. This heuristic
    is intended to make testing the application during development
    easier.
  + GLib ≥ 2.63.1 is now required.
  + Fixed various memory leaks, warnings, and a memory safety bug.
  + Updated translations.
- Pass -Dparental_controls=disabled to meson until we have the
  malcontent library packaged.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + The final page has been revamped, with minor typography tweaks
    to other pages.
  + The timezone map was updated.
  + Three pages have been removed since they were unused in all
    known configurations:
  - the region page, which has not displayed even if enabled for
    many years.
  - the software page, which has not displayed for several
    releases due to changes in GNOME Software.
  - the eulas page.
  + Various bugs fixed.
  + Updated translations.
- Drop pkgconfig(packagekit-glib2) BuildRequires: no longer needed.
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Sun Jan  5 2020 bjorn.lie@gmail.com
- Update to version 3.34.3:
  + Updated translations.
* Tue Nov 26 2019 qzhao@suse.com
- Update gnome-initial-setup-smarter.patch: Rebase to
  gnome-initial-setup-3.34.1 for SLE-15-SP2 build(bnc#1156952).
* Thu Oct 24 2019 qzhao@suse.com
- Update gnome-initial-setup.spec
  Drop gnome-initial-setup-disable-dep-on-started-docs.patch
  Drop gnome-initial-setup-mozc-engine-prioritized.patch
  Drop gnome-initial-setup-only-setup-keyboard.patch
  Drop gnome-initial-setup-only-launch-CJK.patch
  to avoid blank docs window appear after gnome-initial-setup
  finished (bnc#1125694, bnc#1131087).
* Sat Oct  5 2019 bjorn.lie@gmail.com
- Update to version 3.34.1:
  + Bugs fixed:
  - Mark “Accept” button as suggested action
  - Disable g-i-s in GDM.
  + Updated translations.
* Tue Sep 24 2019 fezhang@suse.com
- Fix unpackaged files in specfile.
* Wed Sep 18 2019 bjorn.lie@gmail.com
- Update to version 3.34.0:
  + Bugs fixed: Fixes for systemd user instance support.
  + Updated translations.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.92:
  + Translation updates.
  + Changes in version 3.33.91:
  + build: Add a log domain.
  + Translation updates.
  + Changes in version 3.33.90:
  + systemd user instance support. This is inert without
    corresponding changes in other GNOME modules, and can be
    disabled entirely with `-Dsystemd=false` at build time.
  + Other improvements and bug fixes:
  - summary: don't free borrowed password string.
  - data: use a11y menu in initial-setup session.
  - driver: Account for multi monitor when checking for small screen.
  - language: Refactor the logo selection.
  - language: Fix the visibility of the placeholder.
  - summary: Make the page fit narrow screens.
  - Drop the headers for the first rows.
  - account: Drop the avatar button padding.
  - Refactor page headers.
  - data: Update required gnome-settings-daemon plugins.
  + Translation updates.
  + Changes in version 3.33.4:
  + Bugs fixed:
  - Check for errors from newlocale().
  + Translation updates.
  + Changes in version 3.33.2:
  + Bugs fixed:
  - setlocale() usage is not threadsafe.
  - Include bug report URL in .pot file
  + Translation updates.
- Rebase gnome-initial-setup-only-setup-keyboard.patch.
- Depend on systemd.
- Remove setup-shell.desktop from files.
- Add user systemd targets to files.
* Fri Apr  5 2019 bjorn.lie@gmail.com
- Update to version 3.32.1:
  + Updated translations.
* Mon Mar 11 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.92:
  + Connect to GDM as soon as gnome-initial-setup starts and fix
    memory leaks.
  + Improve account page behaviour when offline.
  + Updated translations.
* Wed Feb 27 2019 qzhao@suse.com
- Update gnome-initial-setup-smarter.patch:
  Avoid duplicate privilege requirement(FATE#321126).
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Generate default user account pictures.
  + Fix Meson build with (buggy) Meson 0.48.0 and 0.48.1.
  + Remove Autotools build.
  + Fix various compiler warnings.
  + Add welcome distro logo for openSUSE.
  + Updated translations.
- Switch to meson build system, add meson BuildRequires and macros.
- Drop obsolete intltool BuildRequires: No longer needed.
- Add pkgconfig(packagekit-glib2) BuildRequires: New dependency.
- Refresh patch with refresh_patches service.
* Wed Dec 19 2018 qzhao@suse.com
- Add gnome-initial-setup-smarter.patch,
  Smarter gnome initial configuration: Find a method (better
  upstream compatible) to allow gnome-initial-setup decide the
  pop-ups smartly based on the system wise setup provided by the
  installer(FATE#325763).
  Adapt previous solutions to satisfy this feature. (FATE#321126,
  boo#1067288, bnc#1029083).
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Updated translations.
* Sun Sep  2 2018 luc14n0@linuxmail.org
- Update to version 3.29.92:
  + Improved network page.
  + Fix timezone selection in new-user mode.
  + Properly use libsecret unstable api.
  + Updated translations.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.1:
  + Support more general page skipping.
  + Show the welcome page if the language page is skipped.
  + Look for vendor.conf in /usr/share instead of /var.
  + Go back to allowing weak passwords.
  + Set keyring password for enterprise accounts.
  + Use Debian, Ubuntu logos when appropriate.
  + Fix a crash.
  + Add meson support.
  + Use a new avatar chooser.
  + Updated translations.
* Tue Mar 27 2018 yfjiang@suse.com
- Rebase gnome-initial-setup-disable-dep-on-started-docs.patch: The
  run-welcome-tour stamp file is moved to a global function as
  stated in bgo#777707.
- Enable the following patches on Leap 42.3, Leap 15 and
  later, being consistent with SLE (boo#1086056):
  + gnome-initial-setup-only-launch-CJK.patch
  + gnome-initial-setup-only-setup-keyboard.patch
  + gnome-initial-setup-disable-dep-on-started-docs.patch
- Remove the dependency of gnome-getting-started-docs on Leap, being
  consistent with SLE (boo#1086056).
- Url link fix in spec.
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Sync string changes with gnome-software.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 27 2018 sbrabec@suse.com
- Add missing lang package Recommends (bsc#1038022).
* Sat Feb 10 2018 bjorn.lie@gmail.com
- Update to version 3.27.90:
  + Adjust session components to recent changes.
  + Improve sorting in the language list.
  + Memory leak fixes.
  + Update titlebar when title changes.
  + Updated translations.
* Thu Nov  9 2017 qzhao@suse.com
- Add gnome-initial-setup-mozc-engine-prioritized.patch: Make the
  Mozc input engine as the 1st choice for Japanese environment
  (boo#1067288,bnc#1029083).
* Fri Sep 15 2017 qzhao@suse.com
- Update gnome-initial-setup-disable-dep-on-started-docs.patch:
  Porting to gnome-initial-setup version 3.26.0.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + Updated translations.
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Use Unicode in translatable strings.
  + Adjust to g-s-d's plugin removals.
  + Updated translations.
* Thu Jun 22 2017 zaitor@opensuse.org
- Update to version 3.25.3:
  + Support a vendor configuration file.
  + Update text direction when the locale changes.
  + Allow configuring network connections.
  + Copy monitor configuration to user session.
  + Sync user account page with control-center.
  + Show strength indicator for passwords.
* Thu Jun  1 2017 qzhao@suse.com
- Update gnome-initial-setup-only-setup-keyboard.patch
  gnome-initial-setup-disable-dep-on-started-docs.patch: Porting
  these patches to gnome-initial-setup version 3.24.2.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Fix g-i-s session startup deadlock.
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Use correct capitalization and unicode characters.
  + Exit gracefully when disabled systemwide.
  + Adjust to gnome-settings-daemon changes.
  + Port network page to use libnm instead of libnm-glib.
  + Updated translations.
- Update BuildRequires relating to upstreams port to libnm:
  + Remove pkgconfig(libnm-glib), pkgconfig(libnm-gtk) and
    pkgconfig(libnm-util).
  + Add pkgconfig(libnm) and pkgconfig(libnma).
* Wed Nov  9 2016 dimstar@opensuse.org
- Update to version 3.23.1:
  + Clarify presentation of privacy policies.
  + Updated translations.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Clarify privacy policy links.
  + Updated translations.
* Mon Sep 19 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Port timezone page to use new Geoclue convencience library.
  + Minor UI fixes on privacy page.
  + Correct license of um-realm-manager.
  + Updated translations.
- Replace pkgconfig(geoclue-2.0) for pkgconfig(libgeoclue-2.0), and
  add pkgconfig(geocode-glib-1.0) BuildRequires following upstreams
  port.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Better handling of small screens.
  + Add a page to configure software sources.
  + Updated translations.
* Mon May 23 2016 yfjiang@suse.com
- Add gnome-initial-setup-disable-dep-on-started-docs.patch:
  Dismiss the yelp help page after the initial setup
  (FATE#321126).
* Mon May 16 2016 yfjiang@suse.com
- Add gnome-initial-setup-only-setup-keyboard.patch: Only setup the
  keyboard and IM as required (FATE#321126).
* Tue May 10 2016 qzhao@suse.com
- Add gnome-initial-setup-only-launch-CJK.patch: In SLED, it will
  active if user's language is Chinese/Japanese/Korean, and
  deactive in other language (FATE#321126).
* Sun May  8 2016 qzhao@suse.com
- Import gnome-initial-setup to SLE12:SP3(FATE#321126, bsc#988350).
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Thu Apr  7 2016 zaitor@opensuse.org
- Drop pkgconfig(clutter-gst-2.0) and pkgconfig(clutter-x11-1.0)
  BuildRequires: Not hard dependencies anymore.
- Add pkgconfig(json-glib-1.0) BuildRequires: Configure looks for
  it, so add it to make sure it's pulled in.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Add a translator comment for 'Welcome!'.
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Visual refinements on online accounts page.
  + Minor tweaks on the privacy and accounts pages.
  + Ensure keyring gets created for new users.
  + Updated translations.
- Changes from version 3.19.90:
  + Visual refresh for the 'ready to go' page.
* Mon Feb 22 2016 dimstar@opensuse.org
- Add gnome-getting-started-docs Requires: once the g-i-s assistant
  is completed, it auto-launches the getting started documentation.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.2:
  + Fix timezone lookup after locale change.
  + Handle screen resolution changes.
  + Design updates to the timezone page.
  + Don't create a keyring for existing users.
  + Updated translations.
* Mon Feb 15 2016 dimstar@opensuse.org
- Create user 'gnome-initial-setup', which is mandatory to make
  this work.
* Mon Nov 23 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Ensure locale region matches the selected language.
  + Sort languages case-insensitively.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Go back to enforcing password policy (bgo#754213).
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Detect enterprise accounts without heuristic (bgo#752980).
  + Don't change keyring password explicitly (bgo#752980).
  + Fix problem with restarting geoclue client.
  + Updated translations.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Create keyring initially unencrypted.
  + Password page refinements (bgo#735578).
  + Make policy dialog resize properly (bgo#749426).
  + Use correct key for privacy policy (bgo#749545).
  + Handle disabled network better.
  + Avoid a crash on language change (bgo#752134).
  + Make gnome-shell launch first.
  + AVoid a race in launching welcome tour.
  + Updated translations.
* Fri May 22 2015 dimstar@opensuse.org
- Update to version 3.16.3:
  + Avoid keyring problems with preexisting passwordless accounts.
  + Improve password page.
  + Look for the right key in os-release for privacy policy.
  + Make policy dialog resize properly.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Stop using deprecated API.
  + Improved keyboard navigation.
  + Adapt to gnome-desktop locale codeset changes.
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91.1:
  + Port to Webkit2.
  + Updated translations.
- Replace pkgconfig(webkitgtk-3.0) BuildRequires with
  pkgconfig(webkit2gtk-4.0), following upstreams port to WebKit2.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Fix a possible crash in the network page.
  + Updated translations.
* Wed Feb 25 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Append ibus input sources.
  + Allow resizing on small screens.
  + Improve account creation dialogs.
  + Move privacy page before timezone.
  + Use the permanent bus name for abrtd.
- Update to version 3.15.90:
  + Add a privacy page.
  + Don't wait for GDM to kill us.
  + Updated translations.
- Add pkgconfig(webkitgtk-3.0) BuildRequires: new dependency.
* Wed Feb 25 2015 dimstar@opensuse.org
- Update to version 3.14.3:
  + Fix a crash in the network page.
  + Append ibus sources to input sources list.
  + Allow resizing on small screens.
  + Use header bars on goa dialogs.
  + Fix a crash in the language page.
  + Hide the window instead of letting gdm kill it.
  + Fix a crash in the keyboard page.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2.1:
  + Disable SSLv3 because of POODLE.
- Changes from version 3.14.2:
  + Fix changing the login keyring password.
  + Ensure that we show the selected input source.
  + Preserve system keyboard layouts.
  + Don't choose irrelevant layouts as first level choices.
  + Add a function to detect small screens.
  + Hide images when we have no space for them.
  + Drop the minimum size when we are on a small screen.
  + Updated translations.
- Changes from version 3.14.1:
  + Don't allow to move window.
  + Avoid a crash in input chooser.
  + Require selecting an input source.
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fix skip button showing up on the last page.
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Update to version 3.13.7:
  + Refine spacing and alignment on all pages.
  + keyboard: Show suggestions for the current locale.
  + keyboard: Add all IBus engines.
  + keyboard: Ellipsize long labels.
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.6:
  + language: Drop British English to make page smaller.
  + region: Drop, instead show all locales in the language page.
  + keyboard: Show all layouts (in the expanded list).
  + account: Whitelist realmd actions to enable enterprise setup.
  + timezone: Remove icon to make page smaller.
  + Improve keyboard navigation.
  + Bring back existing-user mode.
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.5:
  + language: Don't dim distro logo.
  + timezone: Make page smaller.
  + input: Fix build without ibus.
  + password: Don't hard-enforce strong passwords.
  + Updated translations.
* Sat Aug 16 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Account:
  - Improve wording.
  - Update to match control-center.
  + Timezone:
  - Add geoclue integration.
  - Add an icon.
  + Password:
  - Update to match control-center.
  - Properly clean up signal handler.
  + Keyring: Open session.
  + Copy-worker: Run in early initialization phase.
  + Updated translations.
- Add pkgconfig(geoclue-2.0) BuildRequires: new dependency.
* Sat Aug 16 2014 wr@rosenauer.org
- Set RPM group to System/GUI/GNOME to match other GNOME packages.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update license to be GPL-2.0: matches COPYING and most files.
  + Two files in the tarball are marked to be GPL-3.0. Upstream has
    been contacted to verify if this is indeed correct (which would
    result the entire binary to become GPL-3.0+, bgo#733593).
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Fix an untranslatable string.
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Fri Mar 21 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Build fixes:
  - Initialize automake earlier.
  - Enable maintainer mode.
  + Update titlebar on locale change.
  + Use distro logo instead of GNOME foot.
  + Timezone Dialog:
  - Ensure map is properly allocated.
  - Draw location marker pixel-aligned.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.91:
- Initial package, version 3.11.91.
